@@ -1,5 +1,6 @@
 import struct
 import logging
+from datetime import datetime, timedelta
 
 _logger = logging.getLogger(__name__)
 
@@ -11,6 +12,14 @@ class DataInputStream:
     def read_boolean(self):
         return struct.unpack('?', self.stream.read(1))[0]
 
+    def read_bytes(self, byte_array):
+        for i in range(len(byte_array)):
+            byte_array[i] = struct.unpack('B', self.stream.read(1))[0]
+        return byte_array
+
+    def read_int_96(self):
+        return struct.unpack('B', self.stream.read(12))[0]
+
     def read_byte(self):
         return struct.unpack('b', self.stream.read(1))[0]
 
@@ -69,8 +78,16 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
             value_array.append(None)
             continue
 
-        if dtype == "LONG" or dtype == "DATE":
+        if dtype == "LONG":
             value_array.append(dis.read_long())
+        elif dtype == "DATE":
+            epoch_days = dis.read_long() * 86400
+            date = datetime.fromtimestamp(epoch_days)
+            value_array.append(date.strftime("%Y-%m-%d"))
+        elif dtype == "DATETIME":
+            epoch_days = dis.read_long() / 1000_000
+            date_time = datetime.fromtimestamp(epoch_days)
+            value_array.append(date_time.strftime("%Y-%m-%d %H:%M:%S"))
         elif dtype == "STRING":
             value_array.append(dis.read_utf().decode())
         elif dtype == "INT":
@@ -90,7 +107,11 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
         elif dtype == "BYTE":
             value_array.append(dis.read_byte())
         elif dtype == "INT96":
-            value_array.append(dis.read_utf())
+            julian_day = dis.read_int()
+            time = dis.read_long()
+            date_time = datetime.fromtimestamp((julian_day - 2440588) * 86400)
+            date_time_with_nanos = date_time + timedelta(microseconds=(time/1000))
+            value_array.append(date_time_with_nanos.strftime("%Y-%m-%d %H:%M:%S"))
         elif dtype == "INTEGER":
             value_array.append(dis.read_int())
 
