@@ -141,12 +141,7 @@ class Connection(object):
             if not authSession:
                 raise ValueError("invalid username or password")
 
-            buffer = self._client.isSchemaSet()
-            buffer = BytesIO(buffer)
-            dis = DataInputStream(buffer)
-            is_schema_set = dis.read_boolean()
-            if not is_schema_set:
-                self._client.setSchema(database)
+            self._client.setSchema(database)
         except Exception as e:
             self._transport.close()
             raise e
